@@ -41,6 +41,7 @@
 #include "gedit-debug.h"
 #include "gedit-view.h"
 #include "gedit-mdi.h"
+#include "gedit-recent.h"
 #include "gedit2.h"
 #include <gtksourceview/gtksourceview.h>
 
@@ -77,11 +78,26 @@ static void 		gedit_prefs_manager_right_margin_changed (GConfClient *client,
 								  guint cnxn_id, 
 								  GConfEntry *entry, 
 								  gpointer user_data);
+static void 		gedit_prefs_manager_hl_current_line_changed (GConfClient *client,
+								  guint cnxn_id, 
+								  GConfEntry *entry, 
+								  gpointer user_data);
+static void 		gedit_prefs_manager_bracket_matching_changed (GConfClient *client,
+								      guint cnxn_id, 
+								      GConfEntry *entry, 
+								      gpointer user_data);
 static void 		gedit_prefs_manager_syntax_hl_enable_changed (GConfClient *client,
 								      guint cnxn_id, 
 								      GConfEntry *entry, 
 								      gpointer user_data);
-
+static void 		gedit_prefs_manager_max_recents_changed (GConfClient *client,
+								 guint cnxn_id, 
+								 GConfEntry *entry, 
+								 gpointer user_data);
+static void		gedit_prefs_manager_auto_save_changed (GConfClient *client,
+							       guint cnxn_id,
+							       GConfEntry *entry,
+							       gpointer user_data);
 static gint window_state = -1;
 static gint window_height = -1;
 static gint window_width = -1;
@@ -144,10 +160,30 @@ gedit_prefs_manager_app_init (void)
 				gedit_prefs_manager_right_margin_changed,
 				NULL, NULL, NULL);
 
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_CURRENT_LINE_DIR,
+				gedit_prefs_manager_hl_current_line_changed,
+				NULL, NULL, NULL);
+
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_BRACKET_MATCHING_DIR,
+				gedit_prefs_manager_bracket_matching_changed,
+				NULL, NULL, NULL);
+
 		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
 				GPM_SYNTAX_HL_ENABLE,
 				gedit_prefs_manager_syntax_hl_enable_changed,
 				NULL, NULL, NULL);
+
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_MAX_RECENTS,
+				gedit_prefs_manager_max_recents_changed,
+				NULL, NULL, NULL);
+
+		gconf_client_notify_add (gedit_prefs_manager->gconf_client,
+				GPM_SAVE_DIR,
+				gedit_prefs_manager_auto_save_changed,
+				NULL, NULL, NULL);
 	}
 
 	return gedit_prefs_manager != NULL;	
@@ -653,6 +689,87 @@ gedit_prefs_manager_line_numbers_changed (GConfClient *client,
 	}
 }
 
+static void 
+gedit_prefs_manager_hl_current_line_changed (GConfClient *client,
+	guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_HIGHLIGHT_CURRENT_LINE) == 0)
+	{
+		gboolean hl;
+			
+		GList *children;
+
+		if (entry->value->type == GCONF_VALUE_BOOL)
+			hl = gconf_value_get_bool (entry->value);	
+		else
+			hl = GPM_DEFAULT_HIGHLIGHT_CURRENT_LINE;
+	
+		children = bonobo_mdi_get_children (BONOBO_MDI (gedit_mdi));
+
+		while (children != NULL)
+		{
+			GList *views = bonobo_mdi_child_get_views (BONOBO_MDI_CHILD (children->data));
+
+			while (views != NULL)
+			{
+				GtkSourceView *v = GTK_SOURCE_VIEW (
+						gedit_view_get_gtk_text_view (GEDIT_VIEW (views->data)));
+			
+				gtk_source_view_set_highlight_current_line (v, hl);
+			
+				views = views->next;
+			}
+		
+			children = children->next;
+		}
+	}
+}
+
+
+static void 
+gedit_prefs_manager_bracket_matching_changed (GConfClient *client,
+	guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_BRACKET_MATCHING) == 0)
+	{
+		GList *docs;
+		GList *l;
+		gboolean enable;
+
+		if (entry->value->type == GCONF_VALUE_BOOL)
+			enable = gconf_value_get_bool (entry->value);
+		else
+			enable = GPM_DEFAULT_BRACKET_MATCHING;
+
+		docs = gedit_get_open_documents ();
+		
+		l = docs;
+		while (l != NULL)
+		{
+			g_return_if_fail (GTK_IS_SOURCE_BUFFER (l->data));
+
+			gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (l->data),
+							      enable);
+
+
+			l = g_list_next (l);		
+		}
+
+		g_list_free (docs);
+	}
+	
+}
+
 static void 
 gedit_prefs_manager_auto_indent_changed (GConfClient *client,
 	guint cnxn_id, GConfEntry *entry, gpointer user_data)
@@ -707,6 +824,7 @@ gedit_prefs_manager_undo_changed (GConfClient *client,
 	{
 		gint ul;
 		GList *docs;
+		GList *l;
 		
 		if (entry->value->type == GCONF_VALUE_INT)
 			ul = gconf_value_get_int (entry->value);
@@ -716,15 +834,17 @@ gedit_prefs_manager_undo_changed (GConfClient *client,
 		ul = CLAMP (ul, -1, 250);
 
 		docs = gedit_get_open_documents ();
-
-		while (docs != NULL)
+		l = docs;
+		while (l != NULL)
 		{
-			GeditDocument *d = GEDIT_DOCUMENT (docs->data);
+			GeditDocument *d = GEDIT_DOCUMENT (l->data);
 
 			gedit_document_set_max_undo_levels (d, ul);
 		
-			docs = g_list_next (docs);
+			l = g_list_next (l);
 		}
+
+		g_list_free (docs);
 	}
 }
 
@@ -863,3 +983,97 @@ gedit_prefs_manager_syntax_hl_enable_changed (GConfClient *client,
 	}
 }
 
+static void
+gedit_prefs_manager_max_recents_changed (GConfClient *client,
+	guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+	gedit_debug (DEBUG_PREFS, "");
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_MAX_RECENTS) == 0)
+	{
+		EggRecentModel *model;
+		gint max;
+
+		if (entry->value->type == GCONF_VALUE_INT)
+		{
+			max = gconf_value_get_int (entry->value);
+
+			if (max < 0)
+				max = GPM_DEFAULT_MAX_RECENTS;
+		}
+		else
+			max = GPM_DEFAULT_MAX_RECENTS;
+
+		model = gedit_recent_get_model ();
+
+		egg_recent_model_set_limit (model, max);
+	}
+}
+
+static void
+gedit_prefs_manager_auto_save_changed (GConfClient *client,
+	guint cnxn_id, GConfEntry *entry, gpointer user_data)
+{
+	GList *docs;
+	GList *l;
+
+	gedit_debug (DEBUG_PREFS, "");
+
+	g_return_if_fail (entry->key != NULL);
+	g_return_if_fail (entry->value != NULL);
+
+	if (strcmp (entry->key, GPM_AUTO_SAVE) == 0)
+	{
+		gboolean auto_save;
+
+		if (entry->value->type == GCONF_VALUE_BOOL)
+			auto_save = gconf_value_get_bool (entry->value);
+		else
+			auto_save = GPM_DEFAULT_AUTO_SAVE;
+
+		docs = gedit_get_open_documents ();
+		l = docs;
+
+		while (l != NULL)
+		{
+			GeditDocument *doc = GEDIT_DOCUMENT (l->data);
+
+			gedit_document_enable_auto_save (doc, auto_save);
+
+			l = g_list_next (l);
+		}
+
+		g_list_free (docs);
+	}
+	else if (strcmp (entry->key,  GPM_AUTO_SAVE_INTERVAL) == 0)
+	{
+		gint auto_save_interval;
+
+		if (entry->value->type == GCONF_VALUE_INT)
+		{
+			auto_save_interval = gconf_value_get_int (entry->value);
+
+			if (auto_save_interval <= 0)
+				auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
+		}
+		else
+			auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
+
+		docs = gedit_get_open_documents ();
+		l = docs;
+		
+		while (l != NULL)
+		{
+			GeditDocument *doc = GEDIT_DOCUMENT (l->data);
+
+			gedit_document_set_auto_save_interval (doc, auto_save_interval);
+
+			l = g_list_next (l);
+		}
+
+		g_list_free (docs);
+	}
+}
