@@ -31,12 +31,10 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n.h>
 #include <glade/glade-xml.h>
-#include <libgnome/libgnome.h>
 #include <gtk/gtk.h>
 
-#include <glib/gslist.h>
-
 #include "gedit-spell-language-dialog.h"
 
 enum
@@ -89,7 +87,6 @@ dialog_response_handler (GtkDialog *dlg, gint res_id,  GeditSpellLanguageDialog
 			/* FIXME */
 
 			break;
-
 	
 		default:
 			gtk_widget_destroy (dialog->dialog);
@@ -195,6 +192,15 @@ scroll_to_selected (GtkTreeView *tree_view)
 	}
 }
 
+static void
+language_row_activated (GtkTreeView *tree_view,
+			GtkTreePath *path,
+			GtkTreeViewColumn *column,
+			GeditSpellLanguageDialog *dialog)
+{
+	gtk_dialog_response (GTK_DIALOG (dialog->dialog), GTK_RESPONSE_OK);
+}
+
 static GeditSpellLanguageDialog *
 get_languages_dialog (GeditSpellChecker *spell_checker)
 {
@@ -246,8 +252,7 @@ get_languages_dialog (GeditSpellChecker *spell_checker)
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->languages_treeview), dialog->model);
 
-	init_languages_treeview_model (dialog);
-
+	
 	/* Add the encoding column */
 	cell = gtk_cell_renderer_text_new ();
 	column = gtk_tree_view_column_new_with_attributes (_("Languages"), cell, 
@@ -258,16 +263,18 @@ get_languages_dialog (GeditSpellChecker *spell_checker)
 	gtk_tree_view_set_search_column (GTK_TREE_VIEW (dialog->languages_treeview),
 			COLUMN_LANGUAGE_NAME);
 
+	init_languages_treeview_model (dialog);
+
 	g_signal_connect (G_OBJECT (dialog->languages_treeview), "realize", 
-			  G_CALLBACK (scroll_to_selected), 
-			  dialog);
-	
+			  G_CALLBACK (scroll_to_selected), dialog);
+	g_signal_connect (G_OBJECT (dialog->languages_treeview), "row-activated", 
+			  G_CALLBACK (language_row_activated), dialog);
+
 	g_object_unref (gui);
 
 	return dialog;
 }
 
-
 void 
 gedit_spell_language_dialog_run (GeditSpellChecker *spell_checker, GtkWindow *parent)
 {
